/* InterfaceBuilder - IBProjects.h
 * Copyright (c) 1996 NeXT Software, Inc.
 * All rights reserved.
 */

#import <Foundation/Foundation.h>
#import <InterfaceBuilder/IBSystem.h>

@protocol IBProjects <NSObject>

/* Returns the name of the project. */
- (NSString *)projectName;

/* Returns the directory for the project. */
- (NSString *)projectDirectory;

/* Returns the localization directory for the project. */
- (NSString *)languageDirectory;

/* Returns the full path to `file' in the project. */
- (NSString *)pathForFile:(NSString *)file;

/* Returns the project immediately above this project in the project
 * hierarchy.  Returns nil if this project is the root project. */
- (id <IBProjects>)superproject;

/* Returns an array of objects conforming to the IBProjects protocol
 * of the subprojects of this project. */
- (NSArray *)subprojects;

/* Returns the project at the top of the project hierarchy for this
 * project.  Returns self if this project is the root project. */
- (id <IBProjects>)rootProject;

/* Returns YES if self is a subproject of `otherProject'. */
- (BOOL)isDescendantOfProject:(id <IBProjects>)otherProject;

/* Returns YES if self is a superproject of `otherProject'. */
- (BOOL)isAncestorOfProject:(id <IBProjects>)otherProject;

/* Returns the files associated with `fileKey'. */
- (NSArray *)filesForKey:(NSString *)fileKey;

/* Returns YES if `file' is one of the files associated with `fileKey'. */
- (BOOL)containsFile:(NSString *)file forKey:(NSString *)fileKey;

/* Returns YES if `file' is localized (i.e., if it's in the language
 * directory for the project); NO otherwise. */
- (BOOL)fileIsLocalized:(NSString *)file;

@end

IB_EXTERN NSString *IBProjectSourcesFileKey;
IB_EXTERN NSString *IBProjectHeadersFileKey;
IB_EXTERN NSString *IBProjectInterfacesFileKey;
IB_EXTERN NSString *IBProjectResourcesFileKey;
IB_EXTERN NSString *IBProjectSubprojectsFileKey;
IB_EXTERN NSString *IBProjectContextHelpFilesFileKey;
IB_EXTERN NSString *IBProjectDocumentationFilesFileKey;
IB_EXTERN NSString *IBProjectLibrariesFileKey;
IB_EXTERN NSString *IBProjectFrameworksFileKey;
IB_EXTERN NSString *IBProjectSupportingFilesFileKey;
